package it.eng.spago.jbi.init;

import it.eng.spago.base.SourceBean;
import it.eng.spago.configuration.ConfigSingleton;
import it.eng.spago.init.InitializerIFace;
import it.eng.spago.jbi.Constants;
import it.eng.spago.jbi.component.ServiceUnitManagerProvider;
import it.eng.spago.tracing.TracerSingleton;

import java.util.Iterator;
import java.util.List;

/**
 * Initializes the Content Management System 
 * using some configuration parameters.
 * The class is called from Spago Framework during the 
 * Application Start-Up.
 * Creates the repository and all objects necessary for using it within SagoCms  
 */
public class JBIInitializer implements InitializerIFace {
	
	/** 
	 * SourceBean that contains the configuration parameters
	 */
	private SourceBean _config = null;

	
    /* (non-Javadoc)
     * @see it.eng.spago.init.InitializerIFace#init(it.eng.spago.base.SourceBean)
     */
    public void init(SourceBean config) {
    	_config = config;
    	ConfigSingleton configSingleton = ConfigSingleton.getInstance();
        List containers = configSingleton.getAttributeAsList("JBI.CONTAINER");

        for (Iterator it = containers.iterator(); it.hasNext();) {
            SourceBean containerProviderBean = (SourceBean) it.next();
            String containerProviderClass = (String)containerProviderBean.getAttribute("CLASS");
            String containerProviderName = (String)containerProviderBean.getAttribute("NAME");
            
            try {
                ServiceUnitManagerProvider provider = (ServiceUnitManagerProvider)Class.forName(containerProviderClass).newInstance();
                JBIManager.registerContainer(provider, containerProviderName);
            } catch (Exception ex) {
                TracerSingleton.log(Constants.MODULE_NAME, TracerSingleton.CRITICAL,
                        "JBIInitializer::init:", ex);
            }
        }
        JBIManager.setDefaultContainer((String)configSingleton.getAttribute("JBI.DEFAULT_CONTAINER.NAME"));
    }
    
    /**
     * return the SourceBean which contains the configuration
     * of the repository.
     */
	public SourceBean getConfig() {
		return _config;
	}

	
}
